document.addEventListener('DOMContentLoaded', function() {
  // Smooth scrolling for anchor links
  document.querySelectorAll('a[href^="#"]').forEach(anchor => {
    anchor.addEventListener('click', function(e) {
      e.preventDefault();
      
      const targetId = this.getAttribute('href');
      if (targetId === '#') return;
      
      const targetElement = document.querySelector(targetId);
      if (targetElement) {
        const headerHeight = document.querySelector('header').offsetHeight;
        const targetPosition = targetElement.getBoundingClientRect().top + window.pageYOffset - headerHeight;
        
        window.scrollTo({
          top: targetPosition,
          behavior: 'smooth'
        });
      }
    });
  });
  
  // Add active class to nav links when scrolling
  const sections = document.querySelectorAll('section');
  const navLinks = document.querySelectorAll('.nav-links a');
  
  window.addEventListener('scroll', function() {
    let current = '';
    
    sections.forEach(section => {
      const sectionTop = section.offsetTop;
      const sectionHeight = section.clientHeight;
      
      if (pageYOffset >= (sectionTop - 300)) {
        current = section.getAttribute('id');
      }
    });
    
    navLinks.forEach(link => {
      link.classList.remove('active');
      if (link.getAttribute('href') === `#${current}`) {
        link.classList.add('active');
      }
    });
  });
  
  // Simple form validation
  const contactForm = document.querySelector('.contact-form form');
  if (contactForm) {
    contactForm.addEventListener('submit', function(e) {
      const name = this.querySelector('input[name="name"]');
      const email = this.querySelector('input[name="email"]');
      const message = this.querySelector('textarea[name="message"]');
      let isValid = true;
      
      if (!name.value.trim()) {
        name.style.borderColor = 'red';
        isValid = false;
      } else {
        name.style.borderColor = '';
      }
      
      if (!email.value.trim() || !email.value.includes('@')) {
        email.style.borderColor = 'red';
        isValid = false;
      } else {
        email.style.borderColor = '';
      }
      
      if (!message.value.trim()) {
        message.style.borderColor = 'red';
        isValid = false;
      } else {
        message.style.borderColor = '';
      }
      
      if (!isValid) {
        e.preventDefault();
        alert('Please fill out all fields correctly.');
      } else {
        // In a real implementation, you would submit the form here
        alert('Message sent successfully!');
        this.reset();
        e.preventDefault();
      }
    });
  }
});